@@ -1,6 +1,7 @@
 package App::githook_perltidy;
+use strict;
 
-our $VERSION = '0.12.0';
+our $VERSION = '0.12.1_1';
 
 1;
 
@@ -12,7 +13,7 @@ App::githook_perltidy - legacy package for dependencies
 
 =head1 VERSION
 
-0.12.0 (2018-08-02)
+0.12.1_1 (2018-08-19)
 
 =head1 DESCRIPTION
 
